# coding: utf-8

# flake8: noqa

"""
    Flywheel

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.2.0-rc.9
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import


import os
import platform
import logging

log = logging.getLogger('Flywheel')

from flywheel.configuration import Configuration
from flywheel.api_client import  ApiClient
import flywheel.api

SDK_VERSION = "2.2.0rc9"

def config_from_api_key(api_key):
    parts = api_key.split(':')
    if len(parts) < 2:
        raise Exception('Invalid API key')

    host = parts[0]
    if len(parts) == 2:
        key = parts[1]
        port = '443'
    else:
        port = parts[1]
        key = parts[-1]

    if '__force_insecure' in parts:
        scheme = 'http'
    else:
        scheme = 'https'

    config = Configuration()
    config.host = '{}://{}:{}/api'.format(scheme, host, port)
    config.api_key['Authorization'] = key
    config.api_key_prefix['Authorization'] = 'scitran-user'
    return config

class Flywheel:
    def __init__(self, api_key, root=False, skip_version_check=False):
        # Init logging
        logging.basicConfig()

        # Parse API Key and configure api_client
        config = config_from_api_key(api_key)
        self.api_client = ApiClient(config)

        # Root mode
        if root:
            self.api_client.set_default_query_param('root', 'true')

        self.api_client.user_agent = 'Flywheel SDK/{} (Python {}; {})'.format(SDK_VERSION,
            platform.python_version(), platform.system())

        # Initialize Apis
        self.acquisitions_api = flywheel.api.AcquisitionsApi(self.api_client)
        self.analyses_api = flywheel.api.AnalysesApi(self.api_client)
        self.batch_api = flywheel.api.BatchApi(self.api_client)
        self.collections_api = flywheel.api.CollectionsApi(self.api_client)
        self.default_api = flywheel.api.DefaultApi(self.api_client)
        self.devices_api = flywheel.api.DevicesApi(self.api_client)
        self.files_api = flywheel.api.FilesApi(self.api_client)
        self.gears_api = flywheel.api.GearsApi(self.api_client)
        self.groups_api = flywheel.api.GroupsApi(self.api_client)
        self.jobs_api = flywheel.api.JobsApi(self.api_client)
        self.modalities_api = flywheel.api.ModalitiesApi(self.api_client)
        self.projects_api = flywheel.api.ProjectsApi(self.api_client)
        self.reports_api = flywheel.api.ReportsApi(self.api_client)
        self.rules_api = flywheel.api.RulesApi(self.api_client)
        self.sessions_api = flywheel.api.SessionsApi(self.api_client)
        self.users_api = flywheel.api.UsersApi(self.api_client)

        # Perform version check
        self.check_version = not skip_version_check and not os.environ.get('FLYWHEEL_SDK_SKIP_VERSION_CHECK')
        self.api_client.set_version_check_fn(self.perform_version_check)


    def add_acquisition(self, body, **kwargs):  # noqa: E501
        """Create a new acquisition


        :param Acquisition body: (required)
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.acquisitions_api.add_acquisition(body, **kwargs)


    def add_acquisition_analysis(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis. 

        :param str acquisition_id: (required)
        :param AnalysisInputAny body: (required)
        :param bool job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.acquisitions_api.add_acquisition_analysis(acquisition_id, body, **kwargs)


    def add_acquisition_analysis_note(self, acquisition_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to acquisition analysis.


        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.add_acquisition_analysis_note(acquisition_id, analysis_id, body, **kwargs)


    def add_acquisition_note(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Add a note to acquisition.


        :param str acquisition_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.add_acquisition_note(acquisition_id, body, **kwargs)


    def add_acquisition_tag(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Add a tag to acquisition.

        Progates changes to projects, sessions and acquisitions

        :param str acquisition_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.add_acquisition_tag(acquisition_id, body, **kwargs)


    def delete_acquisition(self, acquisition_id, **kwargs):  # noqa: E501
        """Delete a acquisition

        Read-write project permissions are required to delete an acquisition. </br>Admin project permissions are required if the acquisition contains data uploaded by sources other than users and jobs.

        :param str acquisition_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.acquisitions_api.delete_acquisition(acquisition_id, **kwargs)


    def delete_acquisition_analysis(self, acquisition_id, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis


        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.acquisitions_api.delete_acquisition_analysis(acquisition_id, analysis_id, **kwargs)


    def delete_acquisition_analysis_note(self, acquisition_id, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from acquisition analysis.


        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.delete_acquisition_analysis_note(acquisition_id, analysis_id, note_id, **kwargs)


    def delete_acquisition_file(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file. 

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.delete_acquisition_file(acquisition_id, file_name, **kwargs)


    def delete_acquisition_note(self, acquisition_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from acquisition


        :param str acquisition_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.delete_acquisition_note(acquisition_id, note_id, **kwargs)


    def delete_acquisition_tag(self, acquisition_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str acquisition_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.delete_acquisition_tag(acquisition_id, tag_value, **kwargs)


    def download_acquisition_analysis_inputs(self, acquisition_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis inputs.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for all inputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.acquisitions_api.download_acquisition_analysis_inputs(acquisition_id, analysis_id, **kwargs)


    def download_acquisition_analysis_outputs(self, acquisition_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis outputs.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for all outputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.acquisitions_api.download_acquisition_analysis_outputs(acquisition_id, analysis_id, **kwargs)


    def download_file_from_acquisition(self, acquisition_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        return self.acquisitions_api.download_file_from_acquisition(acquisition_id, file_name, dest_file, **kwargs)


    def get_acquisition_download_url(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_download_ticket(acquisition_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_acquisition_analysis(self, acquisition_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.acquisitions_api.download_input_from_acquisition_analysis(acquisition_id, analysis_id, filename, dest_file, **kwargs)


    def get_acquisition_analysis_input_download_url(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_analysis_input_download_ticket(acquisition_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_acquisition_analysis(self, acquisition_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.acquisitions_api.download_output_from_acquisition_analysis(acquisition_id, analysis_id, filename, dest_file, **kwargs)


    def get_acquisition_analysis_output_download_url(self, acquisition_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.acquisitions_api.get_acquisition_analysis_output_download_ticket(acquisition_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_acquisition(self, acquisition_id, **kwargs):  # noqa: E501
        """Get a single acquisition


        :param str acquisition_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Acquisition
        """
        return self.acquisitions_api.get_acquisition(acquisition_id, **kwargs)


    def get_acquisition_analyses(self, acquisition_id, **kwargs):  # noqa: E501
        """Get analyses for acquisition.

        Returns analyses that directly belong to this resource.

        :param str acquisition_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[AnalysisListEntry]
        """
        return self.acquisitions_api.get_acquisition_analyses(acquisition_id, **kwargs)


    def get_acquisition_analysis(self, acquisition_id, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.


        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: AnalysisOutput
        """
        return self.acquisitions_api.get_acquisition_analysis(acquisition_id, analysis_id, **kwargs)


    def get_acquisition_file_info(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Get info for a particular file.


        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: FileEntry
        """
        return self.acquisitions_api.get_acquisition_file_info(acquisition_id, file_name, **kwargs)


    def get_acquisition_note(self, acquisition_id, note_id, **kwargs):  # noqa: E501
        """Get a note on acquisition.


        :param str acquisition_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Note
        """
        return self.acquisitions_api.get_acquisition_note(acquisition_id, note_id, **kwargs)


    def get_acquisition_tag(self, acquisition_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str acquisition_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.acquisitions_api.get_acquisition_tag(acquisition_id, tag_value, **kwargs)


    def get_all_acquisitions(self, **kwargs):  # noqa: E501
        """Get a list of acquisitions


        :param bool async: Perform the request asynchronously
        :return: list[Acquisition]
        """
        return self.acquisitions_api.get_all_acquisitions(**kwargs)


    def modify_acquisition(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Update a acquisition


        :param str acquisition_id: (required)
        :param Acquisition body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.modify_acquisition(acquisition_id, body, **kwargs)


    def modify_acquisition_file(self, acquisition_id, file_name, body, **kwargs):  # noqa: E501
        """Modify a file&#39;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list) 

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param FileEntry body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.acquisitions_api.modify_acquisition_file(acquisition_id, file_name, body, **kwargs)


    def modify_acquisition_file_classification(self, acquisition_id, file_name, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.acquisitions_api.modify_acquisition_file_classification(acquisition_id, file_name, body, **kwargs)


    def modify_acquisition_file_info(self, acquisition_id, file_name, body, **kwargs):  # noqa: E501
        """Update info for a particular file.


        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.modify_acquisition_file_info(acquisition_id, file_name, body, **kwargs)


    def modify_acquisition_info(self, acquisition_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a acquisition.


        :param str acquisition_id: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.modify_acquisition_info(acquisition_id, body, **kwargs)


    def modify_acquisition_note(self, acquisition_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on acquisition.


        :param str acquisition_id: (required)
        :param str note_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.modify_acquisition_note(acquisition_id, note_id, body, **kwargs)


    def rename_acquisition_tag(self, acquisition_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str acquisition_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.acquisitions_api.rename_acquisition_tag(acquisition_id, tag_value, body, **kwargs)


    def replace_acquisition_file(self, acquisition_id, file_name, **kwargs):  # noqa: E501
        """Replace a file


        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.replace_acquisition_file(acquisition_id, file_name, **kwargs)


    def upload_file_to_acquisition(self, acquisition_id, file, **kwargs):  # noqa: E501
        """Upload a file to acquisition.


        :param str acquisition_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.upload_file_to_acquisition(acquisition_id, file, **kwargs)


    def upload_output_to_acquisition_analysis(self, acquisition_id, analysis_id, file, **kwargs):  # noqa: E501
        """Upload an output file to analysis.


        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.acquisitions_api.upload_output_to_acquisition_analysis(acquisition_id, analysis_id, file, **kwargs)


    def add_analysis_note(self, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to analysis.


        :param str analysis_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.add_analysis_note(analysis_id, body, **kwargs)


    def add_analysis_tag(self, analysis_id, body, **kwargs):  # noqa: E501
        """Add a tag to analysis.

        Progates changes to projects, sessions and acquisitions

        :param str analysis_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.add_analysis_tag(analysis_id, body, **kwargs)


    def delete_analysis_note(self, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from analysis


        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.delete_analysis_note(analysis_id, note_id, **kwargs)


    def delete_analysis_tag(self, analysis_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str analysis_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.delete_analysis_tag(analysis_id, tag_value, **kwargs)


    def download_analysis_inputs(self, analysis_id, **kwargs):  # noqa: E501
        """Download analysis inputs.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for all inputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str analysis_id: (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.analyses_api.download_analysis_inputs(analysis_id, **kwargs)


    def download_analysis_outputs(self, analysis_id, **kwargs):  # noqa: E501
        """Download analysis outputs.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for all outputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str analysis_id: (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.analyses_api.download_analysis_outputs(analysis_id, **kwargs)


    def download_input_from_analysis(self, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.analyses_api.download_input_from_analysis(analysis_id, filename, dest_file, **kwargs)


    def get_analysis_input_download_url(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.analyses_api.get_analysis_input_download_ticket(analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_analysis(self, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.analyses_api.download_output_from_analysis(analysis_id, filename, dest_file, **kwargs)


    def get_analysis_output_download_url(self, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.analyses_api.get_analysis_output_download_ticket(analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_analyses(self, container_name, container_id, subcontainer_name, **kwargs):  # noqa: E501
        """Get nested analyses for a container

        Returns analyses that belong to containers of the specified type that belong to ContainerId.  For example: `projects/{ProjectId}/acquisitions/analyses` will return any analyses  that have an acquisition that is under that project as a parent. The `all` keyword is also supported, for example: projects/{ProjectId}/all/analyses  will return any analyses that have any session or acquisition or the project itself as a parent. 

        :param str container_name: The parent container type (required)
        :param str container_id: The parent container id (required)
        :param str subcontainer_name: The sub container type (required)
        :param bool async: Perform the request asynchronously
        :return: list[AnalysisListEntry]
        """
        return self.analyses_api.get_analyses(container_name, container_id, subcontainer_name, **kwargs)


    def get_analysis(self, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.


        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: AnalysisOutput
        """
        return self.analyses_api.get_analysis(analysis_id, **kwargs)


    def get_analysis_note(self, analysis_id, note_id, **kwargs):  # noqa: E501
        """Get a note on analysis.


        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Note
        """
        return self.analyses_api.get_analysis_note(analysis_id, note_id, **kwargs)


    def get_analysis_tag(self, analysis_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str analysis_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.analyses_api.get_analysis_tag(analysis_id, tag_value, **kwargs)


    def modify_analysis_info(self, analysis_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a analysis.


        :param str analysis_id: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.analyses_api.modify_analysis_info(analysis_id, body, **kwargs)


    def modify_analysis_note(self, analysis_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on analysis.


        :param str analysis_id: (required)
        :param str note_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.modify_analysis_note(analysis_id, note_id, body, **kwargs)


    def rename_analysis_tag(self, analysis_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str analysis_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.analyses_api.rename_analysis_tag(analysis_id, tag_value, body, **kwargs)


    def upload_output_to_analysis(self, analysis_id, file, **kwargs):  # noqa: E501
        """Upload an output file to analysis.


        :param str analysis_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.analyses_api.upload_output_to_analysis(analysis_id, file, **kwargs)


    def cancel_batch(self, batch_id, **kwargs):  # noqa: E501
        """Cancel a Job

        Cancels jobs that are still pending, returns number of jobs cancelled. Moves a 'running' batch job to 'cancelled'. 

        :param str batch_id: (required)
        :param bool async: Perform the request asynchronously
        :return: BatchCancelOutput
        """
        return self.batch_api.cancel_batch(batch_id, **kwargs)


    def get_all_batches(self, **kwargs):  # noqa: E501
        """Get a list of batch jobs the user has created.

        Requires login.

        :param bool async: Perform the request asynchronously
        :return: list[Batch]
        """
        return self.batch_api.get_all_batches(**kwargs)


    def get_batch(self, batch_id, **kwargs):  # noqa: E501
        """Get batch job details.


        :param str batch_id: (required)
        :param bool jobs: If true, return job objects instead of job ids
        :param bool async: Perform the request asynchronously
        :return: Batch
        """
        return self.batch_api.get_batch(batch_id, **kwargs)


    def propose_batch(self, body, **kwargs):  # noqa: E501
        """Create a batch job proposal and insert it as &#39;pending&#39;.


        :param BatchProposalInput body: The batch proposal (required)
        :param bool async: Perform the request asynchronously
        :return: BatchProposal
        """
        return self.batch_api.propose_batch(body, **kwargs)


    def start_batch(self, batch_id, **kwargs):  # noqa: E501
        """Launch a job.

        Creates jobs from proposed inputs, returns jobs enqueued. Moves 'pending' batch job to 'running'. 

        :param str batch_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Job]
        """
        return self.batch_api.start_batch(batch_id, **kwargs)


    def add_collection(self, body, **kwargs):  # noqa: E501
        """Create a collection


        :param Collection body: (required)
        :param bool async: Perform the request asynchronously
        :return: CollectionNewOutput
        """
        return self.collections_api.add_collection(body, **kwargs)


    def add_collection_analysis(self, collection_id, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis. 

        :param str collection_id: (required)
        :param AnalysisInputAny body: (required)
        :param bool job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.collections_api.add_collection_analysis(collection_id, body, **kwargs)


    def add_collection_analysis_note(self, collection_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to collection analysis.


        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.add_collection_analysis_note(collection_id, analysis_id, body, **kwargs)


    def add_collection_note(self, collection_id, body, **kwargs):  # noqa: E501
        """Add a note to collection.


        :param str collection_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.add_collection_note(collection_id, body, **kwargs)


    def add_collection_permission(self, collection_id, body, **kwargs):  # noqa: E501
        """Add a permission


        :param str collection_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.add_collection_permission(collection_id, body, **kwargs)


    def add_collection_tag(self, collection_id, body, **kwargs):  # noqa: E501
        """Add a tag to collection.

        Progates changes to projects, sessions and acquisitions

        :param str collection_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.add_collection_tag(collection_id, body, **kwargs)


    def delete_collection(self, collection_id, **kwargs):  # noqa: E501
        """Delete a collection


        :param str collection_id: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.delete_collection(collection_id, **kwargs)


    def delete_collection_analysis(self, collection_id, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis


        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.collections_api.delete_collection_analysis(collection_id, analysis_id, **kwargs)


    def delete_collection_analysis_note(self, collection_id, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from collection analysis.


        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.delete_collection_analysis_note(collection_id, analysis_id, note_id, **kwargs)


    def delete_collection_file(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file. 

        :param str collection_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.delete_collection_file(collection_id, file_name, **kwargs)


    def delete_collection_note(self, collection_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from collection


        :param str collection_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.delete_collection_note(collection_id, note_id, **kwargs)


    def delete_collection_tag(self, collection_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str collection_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.delete_collection_tag(collection_id, tag_value, **kwargs)


    def delete_collection_user_permission(self, collection_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission


        :param str collection_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.delete_collection_user_permission(collection_id, user_id, **kwargs)


    def download_collection_analysis_inputs(self, collection_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis inputs.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for all inputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.collections_api.download_collection_analysis_inputs(collection_id, analysis_id, **kwargs)


    def download_collection_analysis_outputs(self, collection_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis outputs.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for all outputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.collections_api.download_collection_analysis_outputs(collection_id, analysis_id, **kwargs)


    def download_file_from_collection(self, collection_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str collection_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        return self.collections_api.download_file_from_collection(collection_id, file_name, dest_file, **kwargs)


    def get_collection_download_url(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str collection_id: (required)
        :param str file_name: (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.collections_api.get_collection_download_ticket(collection_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_collection_analysis(self, collection_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.collections_api.download_input_from_collection_analysis(collection_id, analysis_id, filename, dest_file, **kwargs)


    def get_collection_analysis_input_download_url(self, collection_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.collections_api.get_collection_analysis_input_download_ticket(collection_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_collection_analysis(self, collection_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.collections_api.download_output_from_collection_analysis(collection_id, analysis_id, filename, dest_file, **kwargs)


    def get_collection_analysis_output_download_url(self, collection_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.collections_api.get_collection_analysis_output_download_ticket(collection_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def get_all_collections(self, **kwargs):  # noqa: E501
        """List all collections.


        :param bool async: Perform the request asynchronously
        :return: list[Collection]
        """
        return self.collections_api.get_all_collections(**kwargs)


    def get_all_collections_curators(self, **kwargs):  # noqa: E501
        """List all curators of collections


        :param bool async: Perform the request asynchronously
        :return: list[InlineResponse2002]
        """
        return self.collections_api.get_all_collections_curators(**kwargs)


    def get_collection(self, collection_id, **kwargs):  # noqa: E501
        """Retrieve a single collection


        :param str collection_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Collection
        """
        return self.collections_api.get_collection(collection_id, **kwargs)


    def get_collection_acquisitions(self, collection_id, **kwargs):  # noqa: E501
        """List acquisitions in a collection


        :param str collection_id: (required)
        :param str session: The id of a session, to which the acquisitions returned will be restricted
        :param bool async: Perform the request asynchronously
        :return: list[Acquisition]
        """
        return self.collections_api.get_collection_acquisitions(collection_id, **kwargs)


    def get_collection_analyses(self, collection_id, **kwargs):  # noqa: E501
        """Get analyses for collection.

        Returns analyses that directly belong to this resource.

        :param str collection_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[AnalysisListEntry]
        """
        return self.collections_api.get_collection_analyses(collection_id, **kwargs)


    def get_collection_analysis(self, collection_id, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.


        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: AnalysisOutput
        """
        return self.collections_api.get_collection_analysis(collection_id, analysis_id, **kwargs)


    def get_collection_file_info(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Get info for a particular file.


        :param str collection_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: FileEntry
        """
        return self.collections_api.get_collection_file_info(collection_id, file_name, **kwargs)


    def get_collection_note(self, collection_id, note_id, **kwargs):  # noqa: E501
        """Get a note on collection.


        :param str collection_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Note
        """
        return self.collections_api.get_collection_note(collection_id, note_id, **kwargs)


    def get_collection_sessions(self, collection_id, **kwargs):  # noqa: E501
        """List sessions in a collection


        :param str collection_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Session]
        """
        return self.collections_api.get_collection_sessions(collection_id, **kwargs)


    def get_collection_tag(self, collection_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str collection_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.collections_api.get_collection_tag(collection_id, tag_value, **kwargs)


    def get_collection_user_permission(self, collection_id, user_id, **kwargs):  # noqa: E501
        """List a user&#39;s permissions for this collection.


        :param str collection_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Permission
        """
        return self.collections_api.get_collection_user_permission(collection_id, user_id, **kwargs)


    def modify_collection(self, collection_id, body, **kwargs):  # noqa: E501
        """Update a collection and its contents


        :param str collection_id: (required)
        :param Collection body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.modify_collection(collection_id, body, **kwargs)


    def modify_collection_file(self, collection_id, file_name, body, **kwargs):  # noqa: E501
        """Modify a file&#39;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list) 

        :param str collection_id: (required)
        :param str file_name: (required)
        :param FileEntry body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.collections_api.modify_collection_file(collection_id, file_name, body, **kwargs)


    def modify_collection_file_classification(self, collection_id, file_name, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str collection_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.collections_api.modify_collection_file_classification(collection_id, file_name, body, **kwargs)


    def modify_collection_file_info(self, collection_id, file_name, body, **kwargs):  # noqa: E501
        """Update info for a particular file.


        :param str collection_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.modify_collection_file_info(collection_id, file_name, body, **kwargs)


    def modify_collection_info(self, collection_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a collection.


        :param str collection_id: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.modify_collection_info(collection_id, body, **kwargs)


    def modify_collection_note(self, collection_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on collection.


        :param str collection_id: (required)
        :param str note_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.modify_collection_note(collection_id, note_id, body, **kwargs)


    def modify_collection_user_permission(self, collection_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#39;s permission for this collection.


        :param str collection_id: (required)
        :param str user_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.modify_collection_user_permission(collection_id, user_id, body, **kwargs)


    def rename_collection_tag(self, collection_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str collection_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.collections_api.rename_collection_tag(collection_id, tag_value, body, **kwargs)


    def replace_collection_file(self, collection_id, file_name, **kwargs):  # noqa: E501
        """Replace a file


        :param str collection_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.replace_collection_file(collection_id, file_name, **kwargs)


    def upload_file_to_collection(self, collection_id, file, **kwargs):  # noqa: E501
        """Upload a file to collection.


        :param str collection_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.upload_file_to_collection(collection_id, file, **kwargs)


    def upload_output_to_collection_analysis(self, collection_id, analysis_id, file, **kwargs):  # noqa: E501
        """Upload an output file to analysis.


        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.collections_api.upload_output_to_collection_analysis(collection_id, analysis_id, file, **kwargs)


    def clean_packfiles(self, **kwargs):  # noqa: E501
        """Clean up expired upload tokens and invalid token directories.


        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.default_api.clean_packfiles(**kwargs)


    def engine_upload(self, body, level, id, job, **kwargs):  # noqa: E501
        """Upload a list of file fields.

        ### Default behavior:  >Uploads a list of file fields sent as file1, file2, etc to an existing   container and updates fields of the files, the container and it's   parents as specified in the metadata fileformfield using the   engine placer class  ### When ``level`` is ``analysis``: > Uploads a list of files to an existing analysis object, marking   all files as ``output=true`` using the job-based analyses placer   class.  See schemas/input/analysis.json 

        :param EnginemetadataEngineUploadInput body: Object encoded as a JSON string. By default JSON must match the specified enginemetadata.json schema If ``level`` is ``analysis``, JSON must match AnalysisUploadMetadata schema  (required)
        :param str level: Which level to store files in (required)
        :param str id: The ID of the container to place files in (required)
        :param str job: Required if ``level`` is ``analysis`` (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.default_api.engine_upload(body, level, id, job, **kwargs)


    def get_config(self, **kwargs):  # noqa: E501
        """Return public Scitran configuration information


        :param bool async: Perform the request asynchronously
        :return: ConfigOutput
        """
        return self.default_api.get_config(**kwargs)


    def get_config_js(self, **kwargs):  # noqa: E501
        """Return public Scitran configuration information in javascript format.


        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.default_api.get_config_js(**kwargs)


    def get_version(self, **kwargs):  # noqa: E501
        """Get server and database schema version info


        :param bool async: Perform the request asynchronously
        :return: VersionOutput
        """
        return self.default_api.get_version(**kwargs)


    def login(self, **kwargs):  # noqa: E501
        """Login

        Scitran Authentication

        :param bool async: Perform the request asynchronously
        :return: AuthLoginOutput
        """
        return self.default_api.login(**kwargs)


    def logout(self, **kwargs):  # noqa: E501
        """Log Out

        Remove authtokens for user

        :param bool async: Perform the request asynchronously
        :return: AuthLogoutOutput
        """
        return self.default_api.logout(**kwargs)


    def resolve_path(self, body, **kwargs):  # noqa: E501
        """Perform path based lookup of nodes in the Flywheel hierarchy

        This will perform a deep lookup of a node (i.e. group/project/session/acquisition) and its children, including any files. The query path is an array of strings in the following order (by default):    * group id   * project label   * session label   * acquisition label  An ID can be used instead of a label by formatting the string as `<id:project_id>`. The full path to the node, and the node's children will be included in the response. 

        :param ResolverInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: ResolverOutput
        """
        return self.default_api.resolve_path(body, **kwargs)


    def search(self, body, **kwargs):  # noqa: E501
        """Perform a search query


        :param SearchQuery body: (required)
        :param bool simple:
        :param int size:
        :param bool async: Perform the request asynchronously
        :return: list[SearchResponse]
        """
        return self.default_api.search(body, **kwargs)


    def create_device(self, body, **kwargs):  # noqa: E501
        """Create a new device.

        Will create a new device record together with an api key. Request must be an admin request. 

        :param Device body: (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.devices_api.create_device(body, **kwargs)


    def get_all_devices(self, **kwargs):  # noqa: E501
        """List all devices.

        Requires login.

        :param bool async: Perform the request asynchronously
        :return: list[Device]
        """
        return self.devices_api.get_all_devices(**kwargs)


    def get_all_devices_status(self, **kwargs):  # noqa: E501
        """Get status for all known devices.

        ok - missing - error - unknown

        :param bool async: Perform the request asynchronously
        :return: DeviceStatus
        """
        return self.devices_api.get_all_devices_status(**kwargs)


    def get_device(self, device_id, **kwargs):  # noqa: E501
        """Get device details


        :param str device_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Device
        """
        return self.devices_api.get_device(device_id, **kwargs)


    def update_device(self, body, **kwargs):  # noqa: E501
        """Modify a device&#39;s type, name, interval, info or set errors.

        Will modify the device record of the device making the request. Type may only be set once if not already specified at creation. Request must be a drone request. 

        :param Device body: (required)
        :param bool async: Perform the request asynchronously
        :return: Device
        """
        return self.devices_api.update_device(body, **kwargs)


    def create_download_ticket(self, body, **kwargs):  # noqa: E501
        """Create a download ticket

        Use filters in the payload to exclude/include files. To pass a single filter, each of its conditions should be satisfied. If a file pass at least one filter, it is included in the targets. 

        :param Download body: Download files with tag 'incomplete' OR type 'dicom' (required)
        :param str prefix: A string to customize the name of the download in the format <prefix>_<timestamp>.tar. Defaults to \"scitran\". 
        :param bool async: Perform the request asynchronously
        :return: DownloadTicketWithSummary
        """
        return self.files_api.create_download_ticket(body, **kwargs)


    def download_ticket(self, ticket, dest_file, **kwargs):  # noqa: E501
        """Download files listed in the given ticket.

        You can use POST to create a download ticket The files listed in the ticket are put into a tar archive 

        :param str ticket: ID of the download ticket (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.files_api.download_ticket(ticket, dest_file, **kwargs)


    def upload_by_label(self, **kwargs):  # noqa: E501
        """Multipart form upload with N file fields, each with their desired filename.

        For technical reasons, no form field names can be repeated. Instead, use (file1, file2) and so forth. A non-file form field called \"metadata\" is also required, which must be a string containing JSON. See api/schemas/input/labelupload.json for the format of this metadata. 

        :param str form_data:
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.files_api.upload_by_label(**kwargs)


    def upload_by_reaper(self, **kwargs):  # noqa: E501
        """Bottom-up UID matching of Multipart form upload with N file fields, each with their desired filename.

        Upload data, allowing users to move sessions during scans without causing new data to be created in referenced project/group.   ### Evaluation Order:  * If a matching acquisition UID is found anywhere on the system, the related files will be placed under that acquisition. * **OR** If a matching session UID is found, a new acquistion is created with the specified UID under that Session UID. * **OR** If a matching group ID and project label are found, a new session and acquisition will be created within that project * **OR** If a matching group ID is found, a new project and session and acquisition will be created within that group. * **OR** A new session and acquisition will be created within a special \"Unknown\" group and project, which is only visible to system administrators. 

        :param str form_data:
        :param bool async: Perform the request asynchronously
        :return: list[FileEntry]
        """
        return self.files_api.upload_by_reaper(**kwargs)


    def upload_by_uid(self, **kwargs):  # noqa: E501
        """Multipart form upload with N file fields, each with their desired filename.

        Same behavior as /api/upload/label,  except the metadata field must be uid format  See api/schemas/input/uidupload.json for the format of this metadata. 

        :param str form_data:
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.files_api.upload_by_uid(**kwargs)


    def upload_match_uid(self, **kwargs):  # noqa: E501
        """Multipart form upload with N file fields, each with their desired filename.

        Accepts uploads to an existing data hierarchy, matched via Session and Acquisition UID See api/schemas/input/uidmatchupload.json for the format of this metadata. 

        :param str form_data:
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.files_api.upload_match_uid(**kwargs)


    def add_gear(self, gear_id_or_name, body, **kwargs):  # noqa: E501
        """Create or update a gear.

        If no existing gear is found, one will be created Otherwise, the specified gear will be updated 

        :param str gear_id_or_name: Name of the gear to interact with (required)
        :param GearDoc body: (required)
        :param bool async: Perform the request asynchronously
        :return: CollectionNewOutput
        """
        return self.gears_api.add_gear(gear_id_or_name, body, **kwargs)


    def delete_gear(self, gear_id_or_name, **kwargs):  # noqa: E501
        """Delete a gear (not recommended)


        :param str gear_id_or_name: Id of the gear to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.gears_api.delete_gear(gear_id_or_name, **kwargs)


    def get_all_gears(self, **kwargs):  # noqa: E501
        """List all gears


        :param bool async: Perform the request asynchronously
        :return: list[GearDoc]
        """
        return self.gears_api.get_all_gears(**kwargs)


    def get_gear(self, gear_id_or_name, **kwargs):  # noqa: E501
        """Retrieve details about a specific gear


        :param str gear_id_or_name: Id of the gear to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: GearDoc
        """
        return self.gears_api.get_gear(gear_id_or_name, **kwargs)


    def get_gear_context(self, gear_id, container_type, container_id, **kwargs):  # noqa: E501
        """Get context values for the given gear and container.

        Ref: https://github.com/flywheel-io/gears/tree/master/spec#contextual-values 

        :param str gear_id: Id of the gear to interact with (required)
        :param str container_type: Type of the container to interact with (required)
        :param str container_id: Id of the container to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: GearContextLookup
        """
        return self.gears_api.get_gear_context(gear_id, container_type, container_id, **kwargs)


    def get_gear_invocation(self, gear_id, **kwargs):  # noqa: E501
        """Get a schema for invoking a gear.


        :param str gear_id: Id of the gear to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.gears_api.get_gear_invocation(gear_id, **kwargs)


    def add_group(self, body, **kwargs):  # noqa: E501
        """Add a group


        :param Group body: (required)
        :param bool async: Perform the request asynchronously
        :return: GroupNewOutput
        """
        return self.groups_api.add_group(body, **kwargs)


    def add_group_permission(self, group_id, body, **kwargs):  # noqa: E501
        """Add a permission


        :param str group_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.add_group_permission(group_id, body, **kwargs)


    def add_group_tag(self, group_id, body, **kwargs):  # noqa: E501
        """Add a tag to group.

        Progates changes to projects, sessions and acquisitions

        :param str group_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.add_group_tag(group_id, body, **kwargs)


    def delete_group(self, group_id, **kwargs):  # noqa: E501
        """Delete a group


        :param str group_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.groups_api.delete_group(group_id, **kwargs)


    def delete_group_tag(self, group_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str group_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.delete_group_tag(group_id, tag_value, **kwargs)


    def delete_group_user_permission(self, group_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission


        :param str group_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.delete_group_user_permission(group_id, user_id, **kwargs)


    def get_all_groups(self, **kwargs):  # noqa: E501
        """List all groups


        :param bool async: Perform the request asynchronously
        :return: list[Group]
        """
        return self.groups_api.get_all_groups(**kwargs)


    def get_group(self, group_id, **kwargs):  # noqa: E501
        """Get group info


        :param str group_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Group
        """
        return self.groups_api.get_group(group_id, **kwargs)


    def get_group_projects(self, group_id, **kwargs):  # noqa: E501
        """Get all projects in a group


        :param str group_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Project]
        """
        return self.groups_api.get_group_projects(group_id, **kwargs)


    def get_group_tag(self, group_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str group_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.groups_api.get_group_tag(group_id, tag_value, **kwargs)


    def get_group_user_permission(self, group_id, user_id, **kwargs):  # noqa: E501
        """List a user&#39;s permissions for this group.


        :param str group_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Permission
        """
        return self.groups_api.get_group_user_permission(group_id, user_id, **kwargs)


    def modify_group(self, group_id, body, **kwargs):  # noqa: E501
        """Update group


        :param str group_id: (required)
        :param Group body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.groups_api.modify_group(group_id, body, **kwargs)


    def modify_group_user_permission(self, group_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#39;s permission for this group.


        :param str group_id: (required)
        :param str user_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.modify_group_user_permission(group_id, user_id, body, **kwargs)


    def rename_group_tag(self, group_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str group_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.groups_api.rename_group_tag(group_id, tag_value, body, **kwargs)


    def accept_failed_output(self, job_id, **kwargs):  # noqa: E501
        """Accept failed job output.

        Remove the 'from_failed_job' flag from the files. Create any automatic jobs for the accepted files. 

        :param str job_id: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.jobs_api.accept_failed_output(job_id, **kwargs)


    def add_job(self, body, **kwargs):  # noqa: E501
        """Add a job


        :param Job body: (required)
        :param bool async: Perform the request asynchronously
        :return: CommonObjectCreated
        """
        return self.jobs_api.add_job(body, **kwargs)


    def add_job_logs(self, job_id, body, **kwargs):  # noqa: E501
        """Add logs to a job.


        :param str job_id: (required)
        :param list[JobLogStatement] body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.jobs_api.add_job_logs(job_id, body, **kwargs)


    def get_job(self, job_id, **kwargs):  # noqa: E501
        """Get job details


        :param str job_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Job
        """
        return self.jobs_api.get_job(job_id, **kwargs)


    def get_job_config(self, job_id, **kwargs):  # noqa: E501
        """Get a job&#39;s config


        :param str job_id: (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.get_job_config(job_id, **kwargs)


    def get_job_logs(self, job_id, **kwargs):  # noqa: E501
        """Get job logs


        :param str job_id: (required)
        :param bool async: Perform the request asynchronously
        :return: JobLog
        """
        return self.jobs_api.get_job_logs(job_id, **kwargs)


    def get_jobs_stats(self, **kwargs):  # noqa: E501
        """Get stats about all current jobs


        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.get_jobs_stats(**kwargs)


    def get_next_job(self, **kwargs):  # noqa: E501
        """Get the next job in the queue

        Used by the engine.

        :param list[str] tags:
        :param bool async: Perform the request asynchronously
        :return: Job
        """
        return self.jobs_api.get_next_job(**kwargs)


    def modify_job(self, job_id, body, **kwargs):  # noqa: E501
        """Update a job.

        Updates timestamp. Enforces a valid state machine transition, if any. Rejects any change to a job that is not currently in 'pending' or 'running' state. Accepts the same body as /api/jobs/add , except all fields are optional. 

        :param str job_id: (required)
        :param object body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.jobs_api.modify_job(job_id, body, **kwargs)


    def prepare_compete(self, job_id, body, **kwargs):  # noqa: E501
        """Create a ticket with the job id and its status.


        :param str job_id: (required)
        :param object body: (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.prepare_compete(job_id, body, **kwargs)


    def reap_jobs(self, **kwargs):  # noqa: E501
        """Reap stale jobs


        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.reap_jobs(**kwargs)


    def retry_job(self, job_id, **kwargs):  # noqa: E501
        """Retry a job.

        The job must have a state of 'failed', and must not have already been retried. The failed jobs config is copied to a new job. The ID of the new job is returned 

        :param str job_id: (required)
        :param bool async: Perform the request asynchronously
        :return: object
        """
        return self.jobs_api.retry_job(job_id, **kwargs)


    def add_modality(self, body, **kwargs):  # noqa: E501
        """Create a new modality.


        :param Modality body: (required)
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.modalities_api.add_modality(body, **kwargs)


    def delete_modality(self, modality_id, **kwargs):  # noqa: E501
        """Delete a modality


        :param str modality_id: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.modalities_api.delete_modality(modality_id, **kwargs)


    def get_all_modalities(self, **kwargs):  # noqa: E501
        """List all modalities.

        Requires login.

        :param bool async: Perform the request asynchronously
        :return: list[Modality]
        """
        return self.modalities_api.get_all_modalities(**kwargs)


    def get_modality(self, modality_id, **kwargs):  # noqa: E501
        """Get a modality&#39;s classification specification


        :param str modality_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Modality
        """
        return self.modalities_api.get_modality(modality_id, **kwargs)


    def replace_modality(self, modality_id, body, **kwargs):  # noqa: E501
        """Replace modality


        :param str modality_id: (required)
        :param Modality body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.modalities_api.replace_modality(modality_id, body, **kwargs)


    def add_project(self, body, **kwargs):  # noqa: E501
        """Create a new project


        :param Project body: (required)
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.projects_api.add_project(body, **kwargs)


    def add_project_analysis(self, project_id, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis. 

        :param str project_id: (required)
        :param AnalysisInputAny body: (required)
        :param bool job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.projects_api.add_project_analysis(project_id, body, **kwargs)


    def add_project_analysis_note(self, project_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to project analysis.


        :param str project_id: (required)
        :param str analysis_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.add_project_analysis_note(project_id, analysis_id, body, **kwargs)


    def add_project_note(self, project_id, body, **kwargs):  # noqa: E501
        """Add a note to project.


        :param str project_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.add_project_note(project_id, body, **kwargs)


    def add_project_permission(self, project_id, body, **kwargs):  # noqa: E501
        """Add a permission


        :param str project_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.add_project_permission(project_id, body, **kwargs)


    def add_project_rule(self, project_id, body, **kwargs):  # noqa: E501
        """Create a new rule for a project.


        :param str project_id: (required)
        :param Rule body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.add_project_rule(project_id, body, **kwargs)


    def add_project_tag(self, project_id, body, **kwargs):  # noqa: E501
        """Add a tag to project.

        Progates changes to projects, sessions and acquisitions

        :param str project_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.add_project_tag(project_id, body, **kwargs)


    def delete_project(self, project_id, **kwargs):  # noqa: E501
        """Delete a project

        Only site admins and users with \"admin\" project permissions may delete a project

        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.projects_api.delete_project(project_id, **kwargs)


    def delete_project_analysis(self, project_id, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis


        :param str project_id: (required)
        :param str analysis_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.projects_api.delete_project_analysis(project_id, analysis_id, **kwargs)


    def delete_project_analysis_note(self, project_id, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from project analysis.


        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.delete_project_analysis_note(project_id, analysis_id, note_id, **kwargs)


    def delete_project_file(self, project_id, file_name, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file. 

        :param str project_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.delete_project_file(project_id, file_name, **kwargs)


    def delete_project_note(self, project_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from project


        :param str project_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.delete_project_note(project_id, note_id, **kwargs)


    def delete_project_tag(self, project_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str project_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.delete_project_tag(project_id, tag_value, **kwargs)


    def delete_project_user_permission(self, project_id, user_id, **kwargs):  # noqa: E501
        """Delete a permission


        :param str project_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.delete_project_user_permission(project_id, user_id, **kwargs)


    def download_file_from_project(self, project_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str project_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        return self.projects_api.download_file_from_project(project_id, file_name, dest_file, **kwargs)


    def get_project_download_url(self, project_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str project_id: (required)
        :param str file_name: (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_download_ticket(project_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_project_analysis(self, project_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.projects_api.download_input_from_project_analysis(project_id, analysis_id, filename, dest_file, **kwargs)


    def get_project_analysis_input_download_url(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_analysis_input_download_ticket(project_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_project_analysis(self, project_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.projects_api.download_output_from_project_analysis(project_id, analysis_id, filename, dest_file, **kwargs)


    def get_project_analysis_output_download_url(self, project_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.projects_api.get_project_analysis_output_download_ticket(project_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_project_analysis_inputs(self, project_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis inputs.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for all inputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.projects_api.download_project_analysis_inputs(project_id, analysis_id, **kwargs)


    def download_project_analysis_outputs(self, project_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis outputs.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for all outputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.projects_api.download_project_analysis_outputs(project_id, analysis_id, **kwargs)


    def end_project_packfile_upload(self, project_id, token, metadata, **kwargs):  # noqa: E501
        """End a packfile upload


        :param str project_id: (required)
        :param str token: (required)
        :param str metadata: string-encoded metadata json object. (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.end_project_packfile_upload(project_id, token, metadata, **kwargs)


    def get_all_projects(self, **kwargs):  # noqa: E501
        """Get a list of projects


        :param bool async: Perform the request asynchronously
        :return: list[Project]
        """
        return self.projects_api.get_all_projects(**kwargs)


    def get_all_projects_groups(self, **kwargs):  # noqa: E501
        """List all groups which have a project in them


        :param bool async: Perform the request asynchronously
        :return: list[Group]
        """
        return self.projects_api.get_all_projects_groups(**kwargs)


    def get_project(self, project_id, **kwargs):  # noqa: E501
        """Get a single project


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Project
        """
        return self.projects_api.get_project(project_id, **kwargs)


    def get_project_acquisitions(self, project_id, **kwargs):  # noqa: E501
        """List all acquisitions for the given project.


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Acquisition]
        """
        return self.projects_api.get_project_acquisitions(project_id, **kwargs)


    def get_project_analyses(self, project_id, **kwargs):  # noqa: E501
        """Get analyses for project.

        Returns analyses that directly belong to this resource.

        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[AnalysisListEntry]
        """
        return self.projects_api.get_project_analyses(project_id, **kwargs)


    def get_project_analysis(self, project_id, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.


        :param str project_id: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: AnalysisOutput
        """
        return self.projects_api.get_project_analysis(project_id, analysis_id, **kwargs)


    def get_project_file_info(self, project_id, file_name, **kwargs):  # noqa: E501
        """Get info for a particular file.


        :param str project_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: FileEntry
        """
        return self.projects_api.get_project_file_info(project_id, file_name, **kwargs)


    def get_project_note(self, project_id, note_id, **kwargs):  # noqa: E501
        """Get a note on project.


        :param str project_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Note
        """
        return self.projects_api.get_project_note(project_id, note_id, **kwargs)


    def get_project_rule(self, project_id, rule_id, **kwargs):  # noqa: E501
        """Get a project rule.


        :param str project_id: (required)
        :param str rule_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Rule
        """
        return self.projects_api.get_project_rule(project_id, rule_id, **kwargs)


    def get_project_rules(self, project_id, **kwargs):  # noqa: E501
        """List all rules for a project.


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Rule]
        """
        return self.projects_api.get_project_rules(project_id, **kwargs)


    def get_project_sessions(self, project_id, **kwargs):  # noqa: E501
        """List all sessions for the given project.


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Session]
        """
        return self.projects_api.get_project_sessions(project_id, **kwargs)


    def get_project_tag(self, project_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str project_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.projects_api.get_project_tag(project_id, tag_value, **kwargs)


    def get_project_user_permission(self, project_id, user_id, **kwargs):  # noqa: E501
        """List a user&#39;s permissions for this project.


        :param str project_id: (required)
        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Permission
        """
        return self.projects_api.get_project_user_permission(project_id, user_id, **kwargs)


    def modify_project(self, project_id, body, **kwargs):  # noqa: E501
        """Update a project


        :param str project_id: (required)
        :param Project body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.modify_project(project_id, body, **kwargs)


    def modify_project_file(self, project_id, file_name, body, **kwargs):  # noqa: E501
        """Modify a file&#39;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list) 

        :param str project_id: (required)
        :param str file_name: (required)
        :param FileEntry body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.projects_api.modify_project_file(project_id, file_name, body, **kwargs)


    def modify_project_file_classification(self, project_id, file_name, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str project_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.projects_api.modify_project_file_classification(project_id, file_name, body, **kwargs)


    def modify_project_file_info(self, project_id, file_name, body, **kwargs):  # noqa: E501
        """Update info for a particular file.


        :param str project_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.modify_project_file_info(project_id, file_name, body, **kwargs)


    def modify_project_info(self, project_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a project.


        :param str project_id: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.modify_project_info(project_id, body, **kwargs)


    def modify_project_note(self, project_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on project.


        :param str project_id: (required)
        :param str note_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.modify_project_note(project_id, note_id, body, **kwargs)


    def modify_project_rule(self, project_id, rule_id, body, **kwargs):  # noqa: E501
        """Update a rule on a project.


        :param str project_id: (required)
        :param str rule_id: (required)
        :param Rule body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.modify_project_rule(project_id, rule_id, body, **kwargs)


    def modify_project_user_permission(self, project_id, user_id, body, **kwargs):  # noqa: E501
        """Update a user&#39;s permission for this project.


        :param str project_id: (required)
        :param str user_id: (required)
        :param Permission body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.modify_project_user_permission(project_id, user_id, body, **kwargs)


    def project_packfile_upload(self, project_id, token, file, **kwargs):  # noqa: E501
        """Add files to an in-progress packfile


        :param str project_id: (required)
        :param str token: (required)
        :param file file: (required)
        :param bool async: Perform the request asynchronously
        :return: list[FileEntry]
        """
        return self.projects_api.project_packfile_upload(project_id, token, file, **kwargs)


    def recalc_all_projects(self, **kwargs):  # noqa: E501
        """Recalculate all sessions against their project templates.

        Iterates all projects that have a session template. Recalculate if projects' sessions satisfy the template. Returns list of modified session ids. 

        :param bool async: Perform the request asynchronously
        :return: SessionTemplateRecalcOutput
        """
        return self.projects_api.recalc_all_projects(**kwargs)


    def recalc_project(self, project_id, **kwargs):  # noqa: E501
        """Recalculate if sessions in the project satisfy the template.

        Returns list of modified session ids.

        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: SessionTemplateRecalcOutput
        """
        return self.projects_api.recalc_project(project_id, **kwargs)


    def remove_project_rule(self, project_id, rule_id, **kwargs):  # noqa: E501
        """Remove a project rule.


        :param str project_id: (required)
        :param str rule_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.projects_api.remove_project_rule(project_id, rule_id, **kwargs)


    def remove_project_template(self, project_id, **kwargs):  # noqa: E501
        """Remove the session template for a project.


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.projects_api.remove_project_template(project_id, **kwargs)


    def rename_project_tag(self, project_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str project_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.rename_project_tag(project_id, tag_value, body, **kwargs)


    def replace_project_file(self, project_id, file_name, **kwargs):  # noqa: E501
        """Replace a file


        :param str project_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.replace_project_file(project_id, file_name, **kwargs)


    def set_project_template(self, project_id, body, **kwargs):  # noqa: E501
        """Set the session template for a project.


        :param str project_id: (required)
        :param ProjectTemplate body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.projects_api.set_project_template(project_id, body, **kwargs)


    def start_project_packfile_upload(self, project_id, **kwargs):  # noqa: E501
        """Start a packfile upload to project


        :param str project_id: (required)
        :param bool async: Perform the request asynchronously
        :return: PackfileStart
        """
        return self.projects_api.start_project_packfile_upload(project_id, **kwargs)


    def upload_file_to_project(self, project_id, file, **kwargs):  # noqa: E501
        """Upload a file to project.


        :param str project_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.upload_file_to_project(project_id, file, **kwargs)


    def upload_output_to_project_analysis(self, project_id, analysis_id, file, **kwargs):  # noqa: E501
        """Upload an output file to analysis.


        :param str project_id: (required)
        :param str analysis_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.projects_api.upload_output_to_project_analysis(project_id, analysis_id, file, **kwargs)


    def get_project_report(self, **kwargs):  # noqa: E501
        """get_project_report


        :param str projects: Specify multiple times to include projects in the report
        :param str start_date: Report start date
        :param str end_date: Report end date
        :param bool async: Perform the request asynchronously
        :return: ReportProject
        """
        return self.reports_api.get_project_report(**kwargs)


    def get_site_report(self, **kwargs):  # noqa: E501
        """get_site_report


        :param bool async: Perform the request asynchronously
        :return: ReportSite
        """
        return self.reports_api.get_site_report(**kwargs)


    def add_site_rule(self, body, **kwargs):  # noqa: E501
        """Create a new site rule.


        :param Rule body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.rules_api.add_site_rule(body, **kwargs)


    def get_site_rule(self, rule_id, **kwargs):  # noqa: E501
        """Get a site rule.


        :param str rule_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Rule
        """
        return self.rules_api.get_site_rule(rule_id, **kwargs)


    def get_site_rules(self, **kwargs):  # noqa: E501
        """List all site rules.


        :param bool async: Perform the request asynchronously
        :return: list[Rule]
        """
        return self.rules_api.get_site_rules(**kwargs)


    def modify_site_rule(self, rule_id, body, **kwargs):  # noqa: E501
        """Update a site rule.


        :param str rule_id: (required)
        :param Rule body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.rules_api.modify_site_rule(rule_id, body, **kwargs)


    def remove_site_rule(self, rule_id, **kwargs):  # noqa: E501
        """Remove a site rule.


        :param str rule_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.rules_api.remove_site_rule(rule_id, **kwargs)


    def add_session(self, body, **kwargs):  # noqa: E501
        """Create a new session


        :param Session body: (required)
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.sessions_api.add_session(body, **kwargs)


    def add_session_analysis(self, session_id, body, **kwargs):  # noqa: E501
        """Create an analysis and upload files.

        When query param \"job\" is \"true\", send JSON to create an analysis and job.  Otherwise, multipart/form-data to upload files and create an analysis. 

        :param str session_id: (required)
        :param AnalysisInputAny body: (required)
        :param bool job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: ContainerNewOutput
        """
        return self.sessions_api.add_session_analysis(session_id, body, **kwargs)


    def add_session_analysis_note(self, session_id, analysis_id, body, **kwargs):  # noqa: E501
        """Add a note to session analysis.


        :param str session_id: (required)
        :param str analysis_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.add_session_analysis_note(session_id, analysis_id, body, **kwargs)


    def add_session_note(self, session_id, body, **kwargs):  # noqa: E501
        """Add a note to session.


        :param str session_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.add_session_note(session_id, body, **kwargs)


    def add_session_tag(self, session_id, body, **kwargs):  # noqa: E501
        """Add a tag to session.

        Progates changes to projects, sessions and acquisitions

        :param str session_id: (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.add_session_tag(session_id, body, **kwargs)


    def delete_session(self, session_id, **kwargs):  # noqa: E501
        """Delete a session

        Read-write project permissions are required to delete a session. </br>Admin project permissions are required if the session or it's acquisitions contain data uploaded by sources other than users and jobs.

        :param str session_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.sessions_api.delete_session(session_id, **kwargs)


    def delete_session_analysis(self, session_id, analysis_id, **kwargs):  # noqa: E501
        """Delete an anaylsis


        :param str session_id: (required)
        :param str analysis_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse200
        """
        return self.sessions_api.delete_session_analysis(session_id, analysis_id, **kwargs)


    def delete_session_analysis_note(self, session_id, analysis_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from session analysis.


        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.delete_session_analysis_note(session_id, analysis_id, note_id, **kwargs)


    def delete_session_file(self, session_id, file_name, **kwargs):  # noqa: E501
        """Delete a file

        A user with read-write or higher permissions on the container may delete files that were uploaded by users or were the output of jobs. (Specifically, files whose `origin.type` is either `job` or `user`.) <br/> A user with admin permissions on the container may delete any file. 

        :param str session_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.delete_session_file(session_id, file_name, **kwargs)


    def delete_session_note(self, session_id, note_id, **kwargs):  # noqa: E501
        """Remove a note from session


        :param str session_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.delete_session_note(session_id, note_id, **kwargs)


    def delete_session_tag(self, session_id, tag_value, **kwargs):  # noqa: E501
        """Delete a tag


        :param str session_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.delete_session_tag(session_id, tag_value, **kwargs)


    def download_file_from_session(self, session_id, file_name, dest_file, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str session_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        return self.sessions_api.download_file_from_session(session_id, file_name, dest_file, **kwargs)


    def get_session_download_url(self, session_id, file_name, **kwargs):  # noqa: E501
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str session_id: (required)
        :param str file_name: (required)
        :param str ticket: The generated ticket id for the download, or present but empty to generate a ticket id
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :param bool async: Perform the request asynchronously
        :return: DownloadTicket
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_download_ticket(session_id, file_name, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_input_from_session_analysis(self, session_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.sessions_api.download_input_from_session_analysis(session_id, analysis_id, filename, dest_file, **kwargs)


    def get_session_analysis_input_download_url(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_analysis_input_download_ticket(session_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_output_from_session_analysis(self, session_id, analysis_id, filename, dest_file, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str dest_file: Destination file path
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.sessions_api.download_output_from_session_analysis(session_id, analysis_id, filename, dest_file, **kwargs)


    def get_session_analysis_output_download_url(self, session_id, analysis_id, filename, **kwargs):  # noqa: E501
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        req_info = {}
        kwargs['_request_out'] = req_info
        kwargs['ticket'] = ''
        data = self.sessions_api.get_session_analysis_output_download_ticket(session_id, analysis_id, filename, **kwargs)
        if data is not None:
            data = req_info['url'] + '?ticket=' + data.ticket
        return data

    def download_session_analysis_inputs(self, session_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis inputs.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for all inputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the inputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.sessions_api.download_session_analysis_inputs(session_id, analysis_id, **kwargs)


    def download_session_analysis_outputs(self, session_id, analysis_id, **kwargs):  # noqa: E501
        """Download analysis outputs.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for all outputs in the anlaysis If no \"ticket\" query param is included, server error 500 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str ticket: ticket id of the outputs to download
        :param bool async: Perform the request asynchronously
        :return: AnalysisFilesCreateTicketOutput
        """
        return self.sessions_api.download_session_analysis_outputs(session_id, analysis_id, **kwargs)


    def get_all_sessions(self, **kwargs):  # noqa: E501
        """Get a list of sessions


        :param bool async: Perform the request asynchronously
        :return: list[Session]
        """
        return self.sessions_api.get_all_sessions(**kwargs)


    def get_session(self, session_id, **kwargs):  # noqa: E501
        """Get a single session


        :param str session_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Session
        """
        return self.sessions_api.get_session(session_id, **kwargs)


    def get_session_acquisitions(self, session_id, **kwargs):  # noqa: E501
        """List acquisitions in a session


        :param str session_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Acquisition]
        """
        return self.sessions_api.get_session_acquisitions(session_id, **kwargs)


    def get_session_analyses(self, session_id, **kwargs):  # noqa: E501
        """Get analyses for session.

        Returns analyses that directly belong to this resource.

        :param str session_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[AnalysisListEntry]
        """
        return self.sessions_api.get_session_analyses(session_id, **kwargs)


    def get_session_analysis(self, session_id, analysis_id, **kwargs):  # noqa: E501
        """Get an analysis.


        :param str session_id: (required)
        :param str analysis_id: (required)
        :param bool inflate_job: Return job as an object instead of an id
        :param bool async: Perform the request asynchronously
        :return: AnalysisOutput
        """
        return self.sessions_api.get_session_analysis(session_id, analysis_id, **kwargs)


    def get_session_file_info(self, session_id, file_name, **kwargs):  # noqa: E501
        """Get info for a particular file.


        :param str session_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: FileEntry
        """
        return self.sessions_api.get_session_file_info(session_id, file_name, **kwargs)


    def get_session_jobs(self, session_id, **kwargs):  # noqa: E501
        """Return any jobs that use inputs from this session


        :param str session_id: (required)
        :param str states: filter results by job state
        :param str tags: filter results by job tags
        :param bool async: Perform the request asynchronously
        :return: SessionJobsOutput
        """
        return self.sessions_api.get_session_jobs(session_id, **kwargs)


    def get_session_note(self, session_id, note_id, **kwargs):  # noqa: E501
        """Get a note on session.


        :param str session_id: (required)
        :param str note_id: (required)
        :param bool async: Perform the request asynchronously
        :return: Note
        """
        return self.sessions_api.get_session_note(session_id, note_id, **kwargs)


    def get_session_tag(self, session_id, tag_value, **kwargs):  # noqa: E501
        """Get the value of a tag, by name.


        :param str session_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param bool async: Perform the request asynchronously
        :return: Tag
        """
        return self.sessions_api.get_session_tag(session_id, tag_value, **kwargs)


    def modify_session(self, session_id, body, **kwargs):  # noqa: E501
        """Update a session


        :param str session_id: (required)
        :param Session body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.modify_session(session_id, body, **kwargs)


    def modify_session_file(self, session_id, file_name, body, **kwargs):  # noqa: E501
        """Modify a file&#39;s attributes

        Note: If modifying a file's modality, the current classification will be cleared (except for items in the \"Custom\" list) 

        :param str session_id: (required)
        :param str file_name: (required)
        :param FileEntry body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.sessions_api.modify_session_file(session_id, file_name, body, **kwargs)


    def modify_session_file_classification(self, session_id, file_name, body, **kwargs):  # noqa: E501
        """Update classification for a particular file.

        If replacing a file's classification, the modality can optionally be modified as well.

        :param str session_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2003
        """
        return self.sessions_api.modify_session_file_classification(session_id, file_name, body, **kwargs)


    def modify_session_file_info(self, session_id, file_name, body, **kwargs):  # noqa: E501
        """Update info for a particular file.


        :param str session_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.modify_session_file_info(session_id, file_name, body, **kwargs)


    def modify_session_info(self, session_id, body, **kwargs):  # noqa: E501
        """Update or replace info for a session.


        :param str session_id: (required)
        :param InfoUpdateInput body: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.modify_session_info(session_id, body, **kwargs)


    def modify_session_note(self, session_id, note_id, body, **kwargs):  # noqa: E501
        """Update a note on session.


        :param str session_id: (required)
        :param str note_id: (required)
        :param Note body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.modify_session_note(session_id, note_id, body, **kwargs)


    def rename_session_tag(self, session_id, tag_value, body, **kwargs):  # noqa: E501
        """Rename a tag.


        :param str session_id: (required)
        :param str tag_value: The tag to interact with (required)
        :param Tag body: (required)
        :param bool async: Perform the request asynchronously
        :return: InlineResponse2001
        """
        return self.sessions_api.rename_session_tag(session_id, tag_value, body, **kwargs)


    def replace_session_file(self, session_id, file_name, **kwargs):  # noqa: E501
        """Replace a file


        :param str session_id: (required)
        :param str file_name: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.replace_session_file(session_id, file_name, **kwargs)


    def upload_file_to_session(self, session_id, file, **kwargs):  # noqa: E501
        """Upload a file to session.


        :param str session_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.upload_file_to_session(session_id, file, **kwargs)


    def upload_output_to_session_analysis(self, session_id, analysis_id, file, **kwargs):  # noqa: E501
        """Upload an output file to analysis.


        :param str session_id: (required)
        :param str analysis_id: (required)
        :param file file: The file to upload (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.sessions_api.upload_output_to_session_analysis(session_id, analysis_id, file, **kwargs)


    def add_user(self, body, **kwargs):  # noqa: E501
        """Add a new user


        :param User body: (required)
        :param bool async: Perform the request asynchronously
        :return: CommonObjectCreated
        """
        return self.users_api.add_user(body, **kwargs)


    def delete_user(self, user_id, **kwargs):  # noqa: E501
        """Delete a user


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: CommonDeletedCount
        """
        return self.users_api.delete_user(user_id, **kwargs)


    def get_all_users(self, **kwargs):  # noqa: E501
        """Return a list of all users


        :param bool async: Perform the request asynchronously
        :return: list[User]
        """
        return self.users_api.get_all_users(**kwargs)


    def get_current_user(self, **kwargs):  # noqa: E501
        """Get information about the current user


        :param bool async: Perform the request asynchronously
        :return: User
        """
        return self.users_api.get_current_user(**kwargs)


    def get_current_user_avatar(self, **kwargs):  # noqa: E501
        """Get the avatar of the current user


        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.users_api.get_current_user_avatar(**kwargs)


    def get_user(self, user_id, **kwargs):  # noqa: E501
        """Get information about the specified user


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: User
        """
        return self.users_api.get_user(user_id, **kwargs)


    def get_user_acquisitions(self, user_id, **kwargs):  # noqa: E501
        """Get all acquisitions that belong to the given user.


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Acquisition]
        """
        return self.users_api.get_user_acquisitions(user_id, **kwargs)


    def get_user_avatar(self, user_id, **kwargs):  # noqa: E501
        """Get the avatar of the specified user


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: None
        """
        return self.users_api.get_user_avatar(user_id, **kwargs)


    def get_user_collections(self, user_id, **kwargs):  # noqa: E501
        """Get all collections that belong to the given user.


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Collection]
        """
        return self.users_api.get_user_collections(user_id, **kwargs)


    def get_user_groups(self, user_id, **kwargs):  # noqa: E501
        """List all groups the specified user is a member of


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Group]
        """
        return self.users_api.get_user_groups(user_id, **kwargs)


    def get_user_projects(self, user_id, **kwargs):  # noqa: E501
        """Get all projects that belong to the given user.


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Project]
        """
        return self.users_api.get_user_projects(user_id, **kwargs)


    def get_user_sessions(self, user_id, **kwargs):  # noqa: E501
        """Get all sessions that belong to the given user.


        :param str user_id: (required)
        :param bool async: Perform the request asynchronously
        :return: list[Session]
        """
        return self.users_api.get_user_sessions(user_id, **kwargs)


    def modify_user(self, user_id, body, **kwargs):  # noqa: E501
        """Update the specified user


        :param str user_id: (required)
        :param User body: Accepts an object matching the User type except all fields are optional  (required)
        :param bool async: Perform the request asynchronously
        :return: CommonModifiedCount
        """
        return self.users_api.modify_user(user_id, body, **kwargs)


    def perform_version_check(self):
        import re
        import warnings

        VERSION_RE = re.compile(r'^(?P<semver>(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<patch>\d+)))?.*')
        release_version = ''
        try:
            version_info = self.default_api.get_version()
            release_version = version_info.release
        except:
            pass

        # If not sdk version
        sdk_version_match = VERSION_RE.match(SDK_VERSION)
        if release_version:
            release_version_match = VERSION_RE.match(release_version)
        else:
            release_version_match = None

        # Log conditionals:
        # 1. Client or server version not set
        # 2. Major version mismatch
        # 3. SDK Minor version > Server Minor version (client features not available on server)
        # 4. SDK Minor version < Server Minor version (new features on server)

        show_pip_message = False
        if sdk_version_match and release_version_match:
            # Compare major/minor version
            sdk_major = int(sdk_version_match.group('major'))
            sdk_minor = int(sdk_version_match.group('minor'))

            release_major = int(release_version_match.group('major'))
            release_minor = int(release_version_match.group('minor'))

            if sdk_major != release_major:
                if SDK_VERSION.find('dev') == -1:
                    # Always print version mismatch
                    warnings.warn('Client version {} does not match server version {}. Please update your client version!'.format(SDK_VERSION, release_version))
                    show_pip_message = True

            elif self.check_version:
                if sdk_minor > release_minor:
                    log.warning('Client version {} is ahead of server version {}. '.format(SDK_VERSION, release_version) +
                        'Not all client functionality will be supported by the server.')
                    show_pip_message = True
                elif sdk_minor < release_minor:
                    log.warning('Client version {} is behind server version {}. '.format(SDK_VERSION, release_version) +
                        'Please consider upgrading your client to access all available functionality.')
                    show_pip_message = True
        elif self.check_version:
            warnings.warn('Client or server version not available! This is an unsupported configuration!')

        if show_pip_message:
            log.warning('Use "pip install flywheel-sdk~={}" '.format(release_version_match.group('semver')) +
                'to install a compatible version for this server')

    def add_nodes_to_collection(self, collection_id, level, node_ids, **kwargs):
        """Generic method to add a list of nodes to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param str level: (required) The level of nodes to add (e.g. session or acquisition)
        :param list[str] node_ids: (required) The list of node ids of type level to add
        :return: None
        """
        update = {
            'contents': {
                'operation': 'add',
                'nodes': [ {'_id': id, 'level': level} for id in node_ids ]
            }
        }
        return self.collections_api.modify_collection(collection_id, update, **kwargs)

    def add_sessions_to_collection(self, collection_id, session_ids, **kwargs):
        """Add a list of sessions to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param list[str] session_ids: (required) The list of session ids to add
        :return: None
        """
        return self.add_nodes_to_collection(collection_id, 'session', session_ids, **kwargs)

    def add_acquisitions_to_collection(self, collection_id, acquisition_ids, **kwargs):
        """Add a list of acquisitions to a collection.

        :param str collection_id: (required) The id of the collection to update
        :param list[str] acquisition_ids: (required) The list of acquisition ids to add
        :return: None
        """
        return self.add_nodes_to_collection(collection_id, 'acquisition', acquisition_ids, **kwargs)

    def change_job_state(self, job_id, state):
        """Change a job state.

        :param str job_id: (required) The id of the job to modify
        :param str state: (required) The new job state
        :return: None
        """
        return self.modify_job(job_id, { 'state': state })

    def resolve(self, path):
        """Perform a path absed lookup of nodes in the Flywheel hierarchy.

        :param str path: (required) The path to resolve
        :return: ResolverOutput
        """
        if not isinstance(path, list):
            path = path.split('/')

        return self.resolve_path(flywheel.ResolverInput(path=path))

    def download_file_from_acquisition_as_data(self, acquisition_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_file_from_acquisition_with_http_info(acquisition_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_acquisition_analysis_as_data(self, acquisition_id, analysis_id, filename, **kwargs):
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_input_from_acquisition_analysis_with_http_info(acquisition_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_acquisition_analysis_as_data(self, acquisition_id, analysis_id, filename, **kwargs):
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str acquisition_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.acquisitions_api.download_output_from_acquisition_analysis_with_http_info(acquisition_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_acquisition_file_classification(self, acquisition_id, file_name, body, **kwargs):
        """Update classification with the provided fields.

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'add': body }
        return self.acquisitions_api.modify_acquisition_file_classification(acquisition_id, file_name, body, **kwargs)

    def replace_acquisition_file_classification(self, acquisition_id, file_name, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_file_classification(acquisition_id, file_name, body, **kwargs)

    def delete_acquisition_file_classification_fields(self, acquisition_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_file_classification(acquisition_id, file_name, body, **kwargs)

    def set_acquisition_file_info(self, acquisition_id, file_name, body, **kwargs):
        """Update info with the provided fields.

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'set': body }
        return self.acquisitions_api.modify_acquisition_file_info(acquisition_id, file_name, body, **kwargs)

    def replace_acquisition_file_info(self, acquisition_id, file_name, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_file_info(acquisition_id, file_name, body, **kwargs)

    def delete_acquisition_file_info_fields(self, acquisition_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str acquisition_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_file_info(acquisition_id, file_name, body, **kwargs)

    def set_acquisition_info(self, acquisition_id, body, **kwargs):
        """Update info with the provided fields.

        :param str acquisition_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'set': body }
        return self.acquisitions_api.modify_acquisition_info(acquisition_id, body, **kwargs)

    def replace_acquisition_info(self, acquisition_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str acquisition_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'replace': body }
        return self.acquisitions_api.modify_acquisition_info(acquisition_id, body, **kwargs)

    def delete_acquisition_info_fields(self, acquisition_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str acquisition_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'delete': body }
        return self.acquisitions_api.modify_acquisition_info(acquisition_id, body, **kwargs)

    def download_input_from_analysis_as_data(self, analysis_id, filename, **kwargs):
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.analyses_api.download_input_from_analysis_with_http_info(analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_analysis_as_data(self, analysis_id, filename, **kwargs):
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.analyses_api.download_output_from_analysis_with_http_info(analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_analysis_info(self, analysis_id, body, **kwargs):
        """Update info with the provided fields.

        :param str analysis_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'set': body }
        return self.analyses_api.modify_analysis_info(analysis_id, body, **kwargs)

    def replace_analysis_info(self, analysis_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str analysis_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'replace': body }
        return self.analyses_api.modify_analysis_info(analysis_id, body, **kwargs)

    def delete_analysis_info_fields(self, analysis_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str analysis_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'delete': body }
        return self.analyses_api.modify_analysis_info(analysis_id, body, **kwargs)

    def download_file_from_collection_as_data(self, collection_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str collection_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.collections_api.download_file_from_collection_with_http_info(collection_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_collection_analysis_as_data(self, collection_id, analysis_id, filename, **kwargs):
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.collections_api.download_input_from_collection_analysis_with_http_info(collection_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_collection_analysis_as_data(self, collection_id, analysis_id, filename, **kwargs):
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str collection_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.collections_api.download_output_from_collection_analysis_with_http_info(collection_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_collection_file_classification(self, collection_id, file_name, body, **kwargs):
        """Update classification with the provided fields.

        :param str collection_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'add': body }
        return self.collections_api.modify_collection_file_classification(collection_id, file_name, body, **kwargs)

    def replace_collection_file_classification(self, collection_id, file_name, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str collection_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_file_classification(collection_id, file_name, body, **kwargs)

    def delete_collection_file_classification_fields(self, collection_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str collection_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_file_classification(collection_id, file_name, body, **kwargs)

    def set_collection_file_info(self, collection_id, file_name, body, **kwargs):
        """Update info with the provided fields.

        :param str collection_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'set': body }
        return self.collections_api.modify_collection_file_info(collection_id, file_name, body, **kwargs)

    def replace_collection_file_info(self, collection_id, file_name, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str collection_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_file_info(collection_id, file_name, body, **kwargs)

    def delete_collection_file_info_fields(self, collection_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str collection_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_file_info(collection_id, file_name, body, **kwargs)

    def set_collection_info(self, collection_id, body, **kwargs):
        """Update info with the provided fields.

        :param str collection_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'set': body }
        return self.collections_api.modify_collection_info(collection_id, body, **kwargs)

    def replace_collection_info(self, collection_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str collection_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'replace': body }
        return self.collections_api.modify_collection_info(collection_id, body, **kwargs)

    def delete_collection_info_fields(self, collection_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str collection_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'delete': body }
        return self.collections_api.modify_collection_info(collection_id, body, **kwargs)

    def download_ticket_as_data(self, ticket, **kwargs):
        """Download files listed in the given ticket.

        You can use POST to create a download ticket The files listed in the ticket are put into a tar archive 

        :param str ticket: ID of the download ticket (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.files_api.download_ticket_with_http_info(ticket, **kwargs)
        if resp:
            return resp.content
        return None

    def download_file_from_project_as_data(self, project_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str project_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_file_from_project_with_http_info(project_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_project_analysis_as_data(self, project_id, analysis_id, filename, **kwargs):
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_input_from_project_analysis_with_http_info(project_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_project_analysis_as_data(self, project_id, analysis_id, filename, **kwargs):
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str project_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.projects_api.download_output_from_project_analysis_with_http_info(project_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_project_file_classification(self, project_id, file_name, body, **kwargs):
        """Update classification with the provided fields.

        :param str project_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'add': body }
        return self.projects_api.modify_project_file_classification(project_id, file_name, body, **kwargs)

    def replace_project_file_classification(self, project_id, file_name, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str project_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_file_classification(project_id, file_name, body, **kwargs)

    def delete_project_file_classification_fields(self, project_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str project_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_file_classification(project_id, file_name, body, **kwargs)

    def set_project_file_info(self, project_id, file_name, body, **kwargs):
        """Update info with the provided fields.

        :param str project_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'set': body }
        return self.projects_api.modify_project_file_info(project_id, file_name, body, **kwargs)

    def replace_project_file_info(self, project_id, file_name, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str project_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_file_info(project_id, file_name, body, **kwargs)

    def delete_project_file_info_fields(self, project_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str project_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_file_info(project_id, file_name, body, **kwargs)

    def set_project_info(self, project_id, body, **kwargs):
        """Update info with the provided fields.

        :param str project_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'set': body }
        return self.projects_api.modify_project_info(project_id, body, **kwargs)

    def replace_project_info(self, project_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str project_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'replace': body }
        return self.projects_api.modify_project_info(project_id, body, **kwargs)

    def delete_project_info_fields(self, project_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str project_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'delete': body }
        return self.projects_api.modify_project_info(project_id, body, **kwargs)

    def download_file_from_session_as_data(self, session_id, file_name, **kwargs):
        """Download a file.

        Files can be downloaded directly from this endpoint with a valid \"Authorization\" header or via a ticket id.  To generate a ticket:   - Make a request with an empty \"ticket\" parameter and a valid \"Authorization\" header. The server will respond with a generated ticket id.   - Make another request with the received ticket id in the \"ticket\" parameter. A valid \"Authorization\" header is no longer required.  When \"view\" is true, [RFC7233](https://tools.ietf.org/html/rfc7233) range request headers are supported. 

        :param str session_id: (required)
        :param str file_name: (required)
        :param bool view: If true, the proper \"Content-Type\" header based on the file's mimetype is set on response If false, the \"Content-Type\" header is set to \"application/octet-stream\" 
        :param bool info: If the file is a zipfile, return a json response of zipfile member information
        :param str member: The filename of a zipfile member to download rather than the entire file
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_file_from_session_with_http_info(session_id, file_name, **kwargs)
        if resp:
            return resp.content
        return None

    def download_input_from_session_analysis_as_data(self, session_id, analysis_id, filename, **kwargs):
        """Download anaylsis inputs with filter.

        If \"ticket\" query param is included and not empty, download inputs. If \"ticket\" query param is included and empty, create a ticket for matching inputs in the anlaysis. If no \"ticket\" query param is included, inputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select inputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_input_from_session_analysis_with_http_info(session_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def download_output_from_session_analysis_as_data(self, session_id, analysis_id, filename, **kwargs):
        """Download anaylsis outputs with filter.

        If \"ticket\" query param is included and not empty, download outputs. If \"ticket\" query param is included and empty, create a ticket for matching outputs in the anlaysis. If no \"ticket\" query param is included, outputs will be downloaded directly. 

        :param str session_id: (required)
        :param str analysis_id: (required)
        :param str filename: regex to select outputs for download (required)
        :return: The binary file data
        """
        kwargs['_return_http_data_only'] = True
        kwargs['_preload_content'] = False
        (resp) = self.sessions_api.download_output_from_session_analysis_with_http_info(session_id, analysis_id, filename, **kwargs)
        if resp:
            return resp.content
        return None

    def set_session_file_classification(self, session_id, file_name, body, **kwargs):
        """Update classification with the provided fields.

        :param str session_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'add': body }
        return self.sessions_api.modify_session_file_classification(session_id, file_name, body, **kwargs)

    def replace_session_file_classification(self, session_id, file_name, body, **kwargs):
        """Entirely replace classification with the provided fields.

        :param str session_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_file_classification(session_id, file_name, body, **kwargs)

    def delete_session_file_classification_fields(self, session_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str session_id: (required)
        :param str file_name: (required)
        :param ClassificationUpdateInput body: (required)
        :return: InlineResponse2003
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_file_classification(session_id, file_name, body, **kwargs)

    def set_session_file_info(self, session_id, file_name, body, **kwargs):
        """Update info with the provided fields.

        :param str session_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'set': body }
        return self.sessions_api.modify_session_file_info(session_id, file_name, body, **kwargs)

    def replace_session_file_info(self, session_id, file_name, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str session_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_file_info(session_id, file_name, body, **kwargs)

    def delete_session_file_info_fields(self, session_id, file_name, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str session_id: (required)
        :param str file_name: (required)
        :param InfoUpdateInput body: (required)
        :return: InlineResponse2001
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_file_info(session_id, file_name, body, **kwargs)

    def set_session_info(self, session_id, body, **kwargs):
        """Update info with the provided fields.

        :param str session_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'set': body }
        return self.sessions_api.modify_session_info(session_id, body, **kwargs)

    def replace_session_info(self, session_id, body, **kwargs):
        """Entirely replace info with the provided fields.

        :param str session_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'replace': body }
        return self.sessions_api.modify_session_info(session_id, body, **kwargs)

    def delete_session_info_fields(self, session_id, body, **kwargs):
        """Delete the specified fields from  + name + .

        :param str session_id: (required)
        :param InfoUpdateInput body: (required)
        :return: None
        """
        body = { 'delete': body }
        return self.sessions_api.modify_session_info(session_id, body, **kwargs)





